@@ -1374,7 +1374,7 @@ class Celery:
     async def _aio_acquire_connection(self, pool=True):
         """Helper for :meth:`connection_or_acquire`."""
         if pool:
-            async with self.aio_pool.acquire() as conn:
+            async with self.aio_pool.acquire(block=True) as conn:
                 yield conn
         else:
             yield self.aconnection_for_write()
@@ -1443,7 +1443,7 @@ class Celery:
             producer = amqp.Producer(connection, auto_declare=False)
 
         async with self.aio_producer_or_acquire(producer) as P:
-            with P.connection._reraise_as_library_errors():
+            with (await P.connection)._reraise_as_library_errors():
                 if not ignored_result:
                     await self.aio_backend.on_task_call(P, task_id)
                 await amqp.send_task_message(P, name, message, **options)
